<div style="display: none;">
    <!-- Button trigger modal -->
    <button type="button" class="btn btn-primary" data-bs-toggle="modal" data-bs-target="#productVariationsModal" id="productVariationsModalBtn">
        Launch product variations modal
    </button>
</div>
  
<!-- Product Variations Modal -->
<div class="modal fade" id="productVariationsModal" data-bs-backdrop="static" data-bs-keyboard="false" tabindex="-1" aria-labelledby="productVariationsModalLabel" aria-hidden="true">
    <div class="modal-dialog modal-dialog-centered modal-xl modal-dialog-scrollable" id="productVariationsModalDialog"></div>
</div>