{% extends 'store/layout/layout.html' %}
{% load static %}


{% block title %}Variation {{variation_id}}{% endblock %}
{% block style %}{% endblock %}

{% block body %}
<div class="container text-center my-2">
    <nav aria-label="breadcrumb">
        <ol class="breadcrumb">
            <li class="breadcrumb-item"><a class="link-danger-dark" href="{% url 'store:homepage' %}">All Products</a></li>
            <li class="breadcrumb-item"><a class="link-danger-dark" href="{% url 'store:product' product_slug=variation.product.slug %}">{{variation.product.title|lower|title}}</a></li>
            <li class="breadcrumb-item active" aria-current="page">{{currency}} {{variation.price}} / {{variation.unit}}</li>
        </ol>
    </nav>
    {% include 'store/includes/variation.html' with variation=variation %}
</div>
{% endblock %}

{% block script %}
<script src="{% static 'store/js/homepage.js' %}"></script>
{% endblock %}