<div class="text-center mt-1">
    {% if messages %}
    <ul class="messages list-unstyled">
        {% for message in messages %}
        <li{% if message.tags %} class="{{ message.tags }}"{% endif %}><strong>{{ message }}</strong></li>
        {% endfor %}
    </ul>
    {% endif %}
</div>