<script id="cancelOrderHandlebars" type="text/x-handlebars-template">
    {% verbatim %}
    <form onsubmit="cancel_order(event, '{{order_id}}');" id="orderCancellationForm">
        <div class="mb-3">
            <label for="OrderCancellationInputReason" class="form-label">Reason (optional)</label>
            <textarea class="form-control" maxlength="200" id="OrderCancellationInputReason" rows="3"></textarea>
        </div>
    </form>
    Are you sure you want to cancel this order?
    <div class="errormessage" id="cancelOrderError"></div>
    {% endverbatim %}
</script>